# Agaric's Content Style Guide

This is our company style guide. It helps us write clear and consistent content. Please use it as a reference when you are writing for Agaric.

## TL;DR

The Agaric Content Style Guide goes into depth on many subjects. It may be more information than you need. Here are the most important things to know.

### Principles

Good content is:

* Authentic, useful, and appropriate

### Voice and tone

Agaric’s voice is:

* Confident but not arrogant
* Cheerful but not Pollyanna-ish
* Unconstrained but not incomprehensible
* Open, curious, eclectic; but not scattered


### Writing about people

We write and build apps with a person-first perspective. Being aware of the impact of your language is one way for us to live out our [values](values).

* Don’t reference age or ability unless it’s relevant to what you’re writing.
* Avoid gendered language and use the singular “they.”
* When writing about a person, use their preferred pronouns; if you don’t know those, just use their name.
* Related resource: [The Conscious Style Guide](https://consciousstyleguide.com/).


### Grammar and mechanics

Some people will read every word you write. Others will just scan. Help everyone by grouping related ideas together and using descriptive headers and subheaders.

Focus your message, and create a hierarchy of information. Lead with the main point or the most important content.

* Use active voice and positive language.
* Use short words and sentences.
* Avoid unnecessary modifiers.
* Use specific examples.
* Avoid vague language.
* Be consistent. Adhere to the copy patterns and style points outlined in this guide.
* Feel free to use contractions.
* Use the serial comma. Otherwise, use common sense. (Also known as the Oxford comma, it helps clarify when items in a list of three, four, or more things are their own items.)
* Don’t use underline, and don’t use any combination of italic, bold, caps, and underline.
* When in doubt, read your writing out loud.

Many of these repeat or reinforce George Orwell's six rules from his essay "Politics and the English Language" (1946), and it is worth keeping all of them in mind, especially the last:

>  (i) Never use a metaphor, simile or other figure of speech which you are used to seeing in print.  
>  (ii) Never use a long word where a short one will do.  
>  (iii) If it is possible to cut a word out, always cut it out.  
>  (iv) Never use the passive where you can use the active.  
>  (v) Never use a foreign phrase, a scientific word, or a jargon word if you can think of an everyday English equivalent.  
>  (vi) Break any of these rules sooner than say anything barbarous.


### Writing for accessibility

* Create a hierarchy, with the most important information first.
Place similar topics in the same paragraph, and clearly separate different topics with headings.
* Use plain language. Write short sentences and familiar words.
* Links should provide information on the associated action or destination. Avoid saying “click here” or “learn more.”
* Avoid using images when descriptive text will do.
* Avoid directional instructions or language that requires the reader to see the layout or design of the page.
* Label inputs on forms with clear names and use appropriate tags. Think carefully about what fields are necessary, and especially which ones you mark as required.


### Writing for translation

* Use active voice.
* Avoid double negatives.
* Use contractions with caution.
* Avoid using synonyms for the same word in a single piece of writing.
* Write briefly, but don’t sacrifice clarity for brevity. You may need to repeat or add words to make the meaning of your sentences clear to a translator.
* Avoid slang, idioms, and cliches.
* Avoid unnecessary abbreviations.


## Writing Goals and Principles

With every piece of content we publish, we aim to:

* **Empower**. Help people build the Open Web and the Free Software Movement by using language that informs them and encourages them to contribute.
* **Inspire**. Lift up our work, our clients' work, and our colleagues' work to inspire others to support them or pursue their own work.

In order to achieve those goals, we make sure our content is:

* **Authentic**. Write about what you are passionate about.
* **Useful**. Before you start writing, ask yourself: What purpose does this serve? Who is going to read it? What do they need to know?
* **Appropriate**. Write in a way that suits the situation. Just like you do in face-to-face conversations, adapt your tone depending on who you’re writing to and what you’re writing about.


## Voice and Tone

One way we write empowering content is by being aware of our voice and our tone.

What’s the difference between voice and tone? Think of it this way: You have the same voice all the time, but your tone changes. You might use one tone when you're out to dinner with your closest friends, and a different tone when you're in a meeting with your boss.

Your tone also changes depending on the emotional state of the person you’re addressing. You wouldn’t want to use the same tone of voice with someone who’s scared or upset as you would with someone who’s laughing.

The same is true for Agaric. Our voice doesn’t change much from day to day, but our tone changes all the time.

### Voice

Agaric’s voice is friendly and straightforward. Our priority is sharing useful information with the wider world. 

Agaric’s voice is:
* Confident but not arrogant
* Cheerful but not pollyannaish
* Unconstrained but not incomprehensible
* Open (curious, eclectic) but not scattered

### Tone

Agaric’s tone is usually informal, but it’s always more important to be clear than entertaining. When you’re writing, consider the reader’s state of mind. Are they curious about a post on our blog? Are they distrustful after being burned by a previous vendor? Are they excited to be engaging in a redesign? Once you have an idea of their emotional state, you can adjust your tone accordingly.

Agaric has a sense of humor, so feel free to be funny when it’s appropriate and when it comes naturally to you. If in any doubt, don't make the joke. Generally avoid humor in written communication to clients.

#### Running gags

##### "The Agaric way"

We've been saying it from the beginning and are only half-serious about it.

### Style tips

Here are a few key elements of writing Agaric’s voice. For more, see the Grammar and mechanics section.

**Active voice**

* Use active voice. Avoid passive voice.
* Avoid slang and jargon Write in plain English.

**Write positively**

* Use positive language rather than negative language.


## Writing About People

We write the same way we build software: with a person-first perspective. Whether you’re writing for an internal or external audience, it's important to write for and about other people in a way that’s compassionate, inclusive, and respectful. Being aware of the impact of your language will help make Agaric a better place to work and a better steward of our values in the world. In this section we'll lay out some guidelines for writing about people with compassion, and share some resources for further learning.

### Age

Don’t reference a person’s age unless it’s relevant to what you’re writing. If it is relevant, include the person’s specific age, offset by commas.
The CEO, 16, just got her driver’s license.
Don’t refer to people using age-related descriptors like “young,” “old,” or “elderly.”

### Ability

Don’t refer to a person’s ability unless it’s relevant to what you’re writing. If you need to mention it, use language that emphasizes the person first: ”she has a disability” rather than “she is disabled.”  When writing about a person with disabilities, don’t use the words “suffer,” “victim,” or “handicapped.” “Handicapped parking” is OK. Avoid using ableist language whenever possible.

### Gender and sexuality

Don’t call groups of people “guys.” "Y'all" is a useful, non-gendered term for addressing groups of people.
Don’t call women “girls.”
Avoid gendered terms in favor of neutral alternatives, like “server” instead of “waitress” and “businessperson” instead of “businessman.”
It’s OK to use “they” as a singular pronoun.

Use the following words as modifiers, but never as nouns:

* lesbian
* gay
* bisexual
* transgender (never "transgendered")
* trans
* queer
* LGBT

Don’t use these words in reference to LGBTQIA people or communities:

* homosexual
* lifestyle
* preference

Don’t use “same-sex” marriage, unless the distinction is relevant to what you’re writing. Avoid using “gay marriage," instead use “marriage.”

When writing about a person, use their communicated pronouns. When in doubt, just ask for their pronouns or use their name.

### Hearing

Use “deaf” as an adjective to describe a person with significant hearing loss. You can also use “partially deaf” or “hard of hearing.”

### Medical conditions

Don’t refer to a person’s medical condition unless it’s relevant to what you’re writing.
If a reference to a person’s medical condition is warranted, emphasize the person first. Don’t call a person with a medical condition a “victim.” Instead, use "patient.""

### Mental and cognitive conditions
Don’t refer to a person’s mental or cognitive condition unless it’s relevant to what you’re writing. Never assume that someone has a medical, mental, or cognitive condition.
Don’t describe a person as “mentally ill.” If a reference to a person’s mental or cognitive condition is warranted, use the same rules as writing about abilities or medical conditions and emphasize the person first.

### Vision
Use the adjective “blind” to describe a person who is unable to see. Use “low vision” to describe a person with limited vision.


## Grammar and mechanics

Adhering to certain rules of grammar and mechanics helps us keep our writing clear and consistent. This section will lay out our house style, which applies to all of our content unless otherwise noted in this guide. (We cover a lot of ground in this section—the search feature will help if you're looking for something in particular.)


### Basics

Write for all readers. Some people will read every word you write. Others will just skim. Help everyone read better by grouping related ideas together and using descriptive headers and subheaders.

Focus your message. Create a hierarchy of information. Lead with the main point or the most important content, in sentences, paragraphs, sections, and pages.

Be concise. Use short words and sentences. Avoid unnecessary modifiers.

Be specific. Avoid vague language. Cut the fluff.

Be consistent. Stick to the copy patterns and style points outlined in this guide.

### Guidelines

#### Abbreviations and acronyms

If there’s a chance your reader won’t recognize an abbreviation or acronym, spell it out the first time you mention it. Then use the short version for all other references. If the abbreviation isn’t clearly related to the full version, specify in parentheses.

First use: Network Operations Center  
Second use: NOC

First use: Coordinated Universal Time (UTC)  
Second use: UTC

If the abbreviation or acronym is well known to your full intended audience, like API or HTML in technical documentation, use it instead (and don’t worry about spelling it out).


#### Active voice

Use active voice. Avoid passive voice.

In active voice, the subject of the sentence does the action. In passive voice, the subject of the sentence has the action done to it.

Yes: Marti logged into the account.  
No: The account was logged into by Marti.

Words like “was” and “by” may indicate that you’re writing in passive voice. Scan for these words and rework sentences where they appear.

One exception is when you want to specifically emphasize the action over the subject. In some cases, this is fine.

> Your account was flagged by our abuse team.

#### Capitalization

We use a few different forms of capitalization. Title case capitalizes the first letter of every word except articles, prepositions, and conjunctions. We use title case for the titles of pages, including blog posts and basic pages.

Sentence case capitalizes the first letter of the first word.
When writing out an email address or website URL, use all lowercase.
micky@agaric.com  
agaric.com  

Don't capitalize random words in the middle of sentences. Here are some words that we never capitalize in a sentence. For more, see the Word list.
website  
internet  
online  
e-mail  

#### Contractions

They’re great! Though you won’t see Micky use them. :) They give your writing an informal, friendly tone. In most cases, use them as you see fit. If you want to convey more authority and formality do not use them.

#### Emoji

Emoji are a fun way to add humor and visual interest to your writing, but use them infrequently and deliberately. Keep them out of blog posts and web copy entirely.

#### Numbers
Spell out a number when it begins a sentence or is under ten. Ten to twenty is a judgement call (but usually spelled out if not paired with numerals). Otherwise, use the numeral. This includes ordinals, too.  
Ten new members started on Monday, and 12 start next week.  
I ate 3 doughnuts at coffee hour.  
Meg won 1st place in last year’s hackathon.  
We hosted a group of 8th graders who are learning to code.  
(Sometimes it feels weird to use "1" instead of "one." Just go with your gut.)  
Numbers over 3 digits get commas:  
999  
1,000  
150,000  
Write out big numbers in full. Abbreviate them if there are space restraints, as in a tweet or a chart: 1k, 150k.  

#### Dates
Generally, spell out the day of the week and the month. Abbreviate only if space is an issue in the app.   
Saturday, January 24  
Sat., Jan. 24  

#### Decimals and fractions
Spell out fractions.  
Yes: two-thirds  
No: 2/3  
Best: ⅔  
Use decimal points when a number can’t be easily written out as a fraction, like 1.375 or 47.2.  

#### Percentages
This depends on context - use the % symbol or spell out "percent" depending on which looks best. 

#### Ranges and spans
Use an en-dash (–­) to indicate a range or span of numbers.  (On Mac: Option + - (dash).  On Windows: Control + -.  On Debian with compose key enabled: compose + --.  
It takes 20–30 days.  

#### Money
When writing about US currency, use the dollar sign before the amount. Include a decimal and number of cents if more than 0.  
$20  
$19.99  
When writing about other currencies, follow the same symbol-amount format:  
¥1  
€1  

#### Telephone numbers
Use dashes without spaces between numbers. Use a country code if your reader is in another country.  
555-867-5309  
+1-404-123-4567  

#### Temperature
Use the degree symbol and the capital F abbreviation for Fahrenheit.  
98°F  

#### Time
Use numerals and am or pm, with a space in between. Don’t use minutes for on-the-hour time.   
7 am   
7:30 pm  
Use an en-dash (–) between times to indicate a time period.   
7am–10:30pm  

Specify time zones when writing about an event or something else people would need to schedule. Since Agaric was founded and has several worker-owners in Boston, Massachusetts, we default to ET.  
Abbreviate time zones within the continental United States as follows:  
Eastern time: ET  
Central time: CT  
Mountain time: MT  
Pacific time: PT  

When referring to international time zones, spell them out: Nepal Standard Time, Australian Eastern Time. If a time zone does not have a set name, use its Coordinated Universal Time (UTC) offset.  

Abbreviate decades when referring to those within the past 100 years.  
the 00s  
the 90s  

When referring to decades more than 100 years ago, be more specific:  
the 1650s  
the 1890s  

#### Punctuation

**Apostrophes**
The apostrophe’s most common use is making a word possessive. If the word already ends in an s and it’s singular, you also add an ‘s. If the word ends in an s and is plural, just add an apostrophe.  
The doughnut thief ate Sam’s doughnut.  
The doughnut thief ate Chris’s doughnut.  
The doughnut thief ate the managers’ doughnuts.  
Apostrophes can also be used to denote that you’ve dropped some letters from a word, usually to match spoken language— an unofficial contraction*. This is fine, but do it sparingly.  

**Colons**
Use a colon (rather than an ellipsis, em dash, or comma) to offset a list.  
Erin ordered three kinds of doughnuts: glazed, chocolate, and pumpkin.  
You can also use a colon to join 2 related phrases. If a complete sentence follows the colon, capitalize the 1st word.  
I was faced with a dilemma: I wanted a doughnut, but I’d just eaten a bagel.  

**Commas**
When writing a list, use the serial comma (also known as the Oxford comma).   
Yes: David admires his parents, Oprah, and Justin Timberlake.  
No: David admires his parents, Oprah and Justin Timberlake.  
Otherwise, use common sense. If you’re unsure, read the sentence out loud. Where you find yourself taking a breath, use a comma.  

**Dashes and hyphens**
Use a hyphen (-) without spaces on either side to link words into single phrase.  
first-time user  
To indicate a span or range, use an n-dash (–).  
Monday–Friday  
Use an em dash (—) with a space after the dash to offset an aside.  Use a true em dash, not hyphens (- or --).  
Multivariate testing—just one of our new Pro features— can help you grow your business.  
Austin thought Brad was the donut thief, but he was wrong— it was Lain.  

**Ellipses**
Ellipses (...) can be used to indicate that you’re trailing off before the end of a thought. Use them sparingly. Don’t use them for emphasis or drama, and don’t use them in titles or headers.
“Where did all those doughnuts go?” Christy asked. Lain said, “I don't know...”  
Ellipses, in brackets, can also be used to show that you're omitting words in a quote.  
“When in the Course of human events it becomes necessary for one people to dissolve the political bands which have connected them with another and to assume among the powers of the earth, [...] a decent respect to the opinions of mankind requires that they should declare the causes which impel them to the separation.”

**Periods**
Periods go inside quotation marks. They go outside parentheses when the parenthetical is part of a larger sentence, and inside parentheses when the parenthetical stands alone.
Christy said, “I ate a doughnut.”  
I ate a doughnut (and I ate a bagel, too).  
I ate a doughnut and a bagel. (The doughnut was Sam’s.)  
Leave a single space between sentences. Unless using a period ligature that provides more space at the end of a sentence than in acronyms, this can be ambiguous: We went to the U.S. I told him.

**Question marks**
Question marks go inside quotation marks if they’re part of the quote. Like periods, they go outside parentheses when the parenthetical is part of a larger sentence, and inside parentheses when the parenthetical stands alone.

**Exclamation points**
Use exclamation points sparingly, and never more than one at a time.  
Exclamation points go inside quotation marks. Like periods and question marks, they go outside parentheses when the parenthetical is part of a larger sentence, and inside parentheses when the parenthetical stands alone.  
Never use exclamation points in failure messages or alerts. When in doubt, avoid!  

**Quotation marks**
Use quotes to refer to words and letters, titles of short works (like articles and poems), and direct quotations.  
Periods and commas go within quotation marks. Question marks within quotes follow logic— if the question mark is part of the quotation, it goes within. If you’re asking a question that ends with a quote, it goes outside the quote.  
Use single quotation marks for quotes within quotes.  
Who was it that said, “A fool and his doughnut are easily parted”?  
Brad said, “A wise man once told me, ‘A fool and his doughnut are easily parted.’”  

**Semicolons**
Go easy on semicolons. They usually support long, complicated sentences that could easily be simplified. Try an em dash (—) instead, or simply start a new sentence.

**Ampersands**
Don't use ampersands unless one is part of a company or brand name.  
Ben and Dan  
Ben & Jerry’s  
People, Places, and Things  

**File extensions**
When referring generally to a file extension type, use all uppercase without a period. Add a lowercase s to make plural.  
GIF  
PDF  
HTML  
JPGs  
When referring to a specific file, the filename should be lowercase:  
slowclap.gif  
MCBenefits.pdf  
ben-twitter-profile.jpg  
ilovedonuts.html  

**Pronouns**
If your subject’s gender is unknown or irrelevant, use “they,” “them,” and “their” as a singular pronoun. Use “he/him/his” and “she/her/her” pronouns as appropriate. Don’t use “one” as a pronoun.  
For more on writing about gender, see Writing about people.  

**Quotes**
When quoting someone in a blog post or other publication, use the past tense.  
“Working with Agaric has helped our business grow,” said Jamie Smith.  

**Names and titles**
The first time you mention a person in writing, refer to them by their first and last names. On all other mentions, refer to them by their first name.  
Capitalize the names of departments and teams (but not the word "team" or "department").  
Marketing team  
Support department  
Capitalize individual job titles when referencing to a specific role. Don't capitalize when referring to the role in general terms.  
Our new Marketing Manager starts today.  
All the managers ate donuts.  
Don't refer to someone as a “ninja,” “rockstar,” or “wizard” unless they literally are one.  

**Schools**
The first time you mention a school, college, or university in a piece of writing, refer to it by its full official name. On all other mentions, use its more common abbreviation.  
Georgia Institute of Technology, Georgia Tech  
Georgia State University, GSU  
States, cities, and countries   
Spell out all city and state names. Don’t abbreviate city names.  
Per AP Style, all cities should be accompanied by their state, with the exception of: Atlanta, Baltimore, Boston, Chicago, Cincinnati, Cleveland, Dallas, Denver, Detroit, Honolulu, Houston, Indianapolis, Las Vegas, Los Angeles, Miami, Milwaukee, Minneapolis, New Orleans, New York, Oklahoma City, Philadelphia, Phoenix, Pittsburgh, St. Louis, Salt Lake City, San Antonio, San Diego, San Francisco, Seattle, Washington.  
On first mention, write out United States. On subsequent mentions, US is fine. The same rule applies to any other country or federation with a common abbreviation (European Union, EU; United Kingdom, UK).  

**URLs and websites**
Capitalize the names of websites and web publications. Don’t italicize.  
Avoid spelling out URLs, but when you need to, leave off the http://www.  

## Writing about Agaric  

Our company's legal entity name is "Agaric, LLC." Our trade name is "Agaric." Use "Agaric, LLC" only when writing legal documents or contracts. Otherwise, use "Agaric."

Always capitalize Agaric.  

Refer to Agaric as “we,” not “it.”  

Capitalize the proper names of Agaric products, features, pages, and tools.   

## Writing about other companies

Honor companies’ own names for themselves and their products. Go by what’s used on their official website. Unless they end with an exclamation point ('!'); that's absurd and will not be respected!

Refer to a company or product as “it” (not “they”).  

**Slang and jargon**

Write in plain English. If you need to use a technical term, briefly define it so everyone can understand.

Agaric’s ops team is constantly scaling our servers to make sure our users have a great experience with our products. One way we do this is with shards, or partitions, that help us better horizontally scale our database infrastructure.

**Text formatting**
Use italics to indicate the title of a long work (like a book, movie, or album) or to emphasize a word.  
Dunston Checks In  
Brandon really loves Dunston Checks In.  
Use italics when citing an example of an element, or referencing button and navigation labels in step-by-step instructions:  
When you're all done, click Send.  
The familiar A/B testing variables—Subject line, From name, and Send time—have now been joined by Content, and up to 3 combinations of a single variable can now be tested at once.
Don’t use underline formatting, and don’t use any combination of italic, bold, caps, and underline.  
Left-align text, never center or right-aligned.  
Leave one space between sentences, never 2.  

**Write positively**
Use positive language rather than negative language. One way to detect negative language is to look for words like “can’t,” “don’t,” etc.  
Yes: To get a donut, stand in line.  
No: You can’t get a donut if you don’t stand in line.  


## Content Types
Content at Agaric takes many forms. Here’s a rundown of the types of content we most often write, the functions they serve, and the teams that handle them.  

### Short

#### Error or failure message
What: Short message that alerts the user to a problem in their account or on their site 
Length: 20-75 words  
Owner: Developer  
Example: Looks like you've left our default header content unmodified. Specifically, we still see ‘Use this area to offer a short preview’ in the pre-header/header area.  

#### Interface copy  
What: Explanatory messaging that guides and informs users  
Length: 10-50 words  
Owner: Developer  
Example: To get started, set a URL to import.  
Social media  
What: Posts on Twitter, Facebook, Instagram, and LinkedIn that highlight blog posts, events, notable Agaric clients, and more  
Length: 20-30 words  
Owner: Marketing, support  
Example: The City of Camrbidge uses Agaric's Find It platform to make it easier for people to find activities, events, and resources. Here's how: https://agaric.coop/work/find-it-cambridge
See also: Writing for social media  

#### Success message  
What: Short, encouraging message letting the user know they’ve accomplished something in the app  
Length: 5-20 words  
Owner: Product  
Example: Excellent! Your account has been created 

### Long

#### Blog post  
What: Informative articles about Agaric work, initiatives, and announcements  
Length: 400-800 words  
Example: Flat Comments in Drupal 8 without Dangerous Secret Threading  
See also: Writing blog posts

#### Email newsletter
What: Email campaigns that market our services/products and inform or empower our users  
Length: 200-1000 words  
Example: We need one!  
See also: Writing email newsletters

#### How To article
What: Easily digestible content that walks users through a process or problem  
Length: 300-1,000 words  
Owner: Knowledge Base  
Example: Getting Started with Lists  
See also: Writing technical content  

#### Legal content  
What: Policies that explain how we protect user privacy and how we handle accounts  
Length: 1,000-4,000 words  
Owner: Legal
Example: Legal: Terms of Use
See also: Writing legal content

#### Press release
What: Quick, informative announcements that we send to our media list and post to our Press Releases page.  
Length: 300-500 words  
Owner: Marketing  
Example: Agaric Launches Data Visualization Platform for Healthcare Providers 


## Web Elements

Every piece of content we publish is supported by a number of smaller pieces. This section lays out our style in regards to these web elements, and explains our approach to the tricky art of SEO.

### Guidelines

#### Alt text
Alt text is a way to label images, and it's especially important for people who can’t see the images on our website. Alt text should describe the image in a brief sentence or two.
For more on how and why we use alt text, read the Accessibility section.

#### Buttons
Buttons should always contain actions. The language should be clear and concise. Capitalize every word, including articles. It’s OK to use an ampersand in button copy.
Standard website buttons include:  
Log In  
Sign Up Free  
Subscribe  
Email Us  
Checkboxes  
Use sentence case for checkboxes.  
Drop-down menus  
Use title case for menu names and sentence case for menu items.  

#### Forms
Form titles should clearly and quickly explain the purpose of the form.  
Use title case for form titles and sentence case for form fields.  
Keep forms as short as possible.  
Only request information that we need and intend to use. Don’t ask for information that could be considered private or personal, including gender. If you need to ask for gender, provide a field the user can fill in on their own, not a drop-down menu.

#### Headings and subheadings
Headings and subheadings organize content for readers. Be generous and descriptive.  
Headings (H1) give people a taste of what they’re about to read. Use them for page and blog titles.  
Subheadings (H2, H3, etc.) break articles into smaller, more specific sections. They give readers avenues into your content and make it more scannable.  
Headings and subheadings should be organized in a hierarchy, with heading first, followed by subheadings in order. (An H2 will nestle under H1, an H3 under H2, and on down.)  
Include the most relevant keywords in your headings and subheadings, and make sure you cover the main point of the content.  
Use title case, unless the heading is a punctuated sentence. If the heading is a punctuated sentence, use sentence case. Use sentence case for subheadings regardless of end punctuation.

#### Links

Provide a link whenever you’re referring to something on an external website. Use links to point users to relevant content and trusted external resources.  
Don’t include preceding articles (a, an, the, our) when you link text. For example:  
Yes: Read the [content style guide](content-style-guide#links) for details.  
No: Read [the content style guide](content-style-guide#links) for details.  

If a link comes at the end of a sentence or before a comma, don’t link the punctuation mark.

Don’t say things like “Click here!” or “Click for more information” or “Read this.” Write the sentence as you normally would, and link relevant keywords.

Links should look different than regular copy, strong text, or emphasis text. They should have a hover state that communicates they’re interactive, and should have a distinct active and visited state. When setting the hover state of links, be sure to include focus state as well, to help readers using assistive technologies and touch devices.


#### Lists

Use lists to present steps, groups, or sets of information. Give context for the list with a brief introduction. Number lists when the order is important, like when you’re describing steps of a process. Don’t use numbers when the list’s order doesn’t matter. 

If one of the list items is a complete sentence, use proper punctuation and capitalization on all of the items. If list items are not complete sentences, don’t use punctuation, but do capitalize the first word of each item.

#### Navigation

Use title case for main or global navigation. Use sentence case for subnavigation.

Navigation links should be clear and concise.


#### Radio Buttons

Use title case for headings and sentence case for button fields.

#### Related articles

Sometimes a long piece of copy lends itself to a list of related links at the end. Don’t go overboard—4 is usually plenty.

Related articles should appear in a logical order, following the step down/step up rule: The first article should be a step down in complexity from the current article. The second one should be a step up in complexity to a more advanced article.

If you can, avoid repeating links from the body text in related articles.

#### Titles

Titles organize pages and guide readers. A title appears at the beginning of a page or section and briefly describes the content that follows.  
Titles are (you guessed it) in title case.  
Don’t use punctuation in a title unless the title is a question.  

#### SEO
We write for humans, not machines. We don't use gross SEO techniques like keyword stuffing to bump search results. But we also want to make it easy for people and search engines to find and share our content. Here are some not-icky ways to do this:  
Organize your page around one topic. Use clear, descriptive terms in titles and headings that relate to the topic at hand.  
Use descriptive headings to structure your page and highlight important information.
Give every image descriptive alt text.  


## Writing Blog Posts
Agaric blog posts are written by people from all over the company, not just those with “writer” in their job titles. We love having experts from around the office blog about their work. The person most familiar with the subject is in the best position to convey it, and the writers on the marketing team can help with brainstorming and editing as needed.


### Basics

We update the main Agaric blog a couple times every month. We generally publish:

* Feature, release, and integration announcements
* Agaric case studies
* Tips and tricks for web developers

We publish blog posts that explain the “why” behind the work we do at Agaric. We want to show people that we're an industry leader and we use our blog to tell the stories behind our work and services.


### Guidelines

When writing for the blog, follow the style points outlined in the Voice and tone and Grammar and mechanics sections. Here are some more general pointers, too.

#### Be casual, but smart

This isn’t a term paper, so there’s no need to be stuffy. Drop some knowledge while casually engaging your readers with conversational language.

#### Be specific

If you're writing about data, put the numbers in context. If you're writing about an Agaric client, give the reader plenty of information about the organization’s purpose, workflow, technical needs and results.

#### Get to the point

Get to the important stuff right away, and don’t bury the kicker. Blog posts should be scannable and easy to digest. Break up your paragraphs into short chunks of three or four sentences, and use subheads. Our users are busy, and we should always keep that in mind.

#### Link it up

Feel free to link away from Agaric if it helps you explain something.

#### Make 'em laugh

Agaric is a fun company, and we want our blog to reflect this. Feel free to throw in a joke here and there, or link out to a funny GIF or YouTube video when appropriate. Just don't overdo it.

#### Use tags and keywords

In Drupal, add keywords that apply to your article. Look through existing posts for common tags. If you’re not sure if a word should be a tag, it probably shouldn’t.

#### Use pictures

Include images in your blog posts when it makes sense. If you’re explaining how to do something, include screenshots to illustrate your point. Make sure to use alt text.


## Writing case studies

*This section is heavily influenced by Nick Disabato of [Draft](https://draft.nu).*

A case study shows potential clients a named real-world client we have worked with, along with the impact (economic or other) we had on their business or organization, with social proof from one or more members of the client’s team.

### What to enforce upfront

This involves three bits that need to be contractually enforced before starting any engagement:

* The client must be explicitly named. 
* The impact must be measurable. We cite a specific number that indicates the impact of our work. No numeric ranges here: only specific, precise numbers.
* Social proof must be present. Get an awesome quotation about the impact of Agaric’s work from the client and publish the case study with their name in it.
* These must be contractually enforced before the engagement begins, because they are always points of contention later.

### Components of a Great Case Study

**The problem.** Explain or enumerate why a client came to Agaric, as well as any unique aspects of their problem.  (The more expensive a problem is for a client, the more clearly we can show our impact.)

**Our thinking.** How did we begin approaching the problem? What research did we conduct to address it? What worked and what did not? What did we try?

**The outcome.** What was the measurable impact of our work?

**A quotation.** What did the client say about our work?

**What happened next.** Did the engagement expand in any capacity? Did we do other valuable things for them that were not part of the initial, agreed-upon scope?

**A call to action.** Case studies exist to generate additional leads for the consultancy, so end with a clear next step for the reader to take – one that probably begins with introducing the kind of work we can do for them, and encourages them to apply.


## Writing about initiatives 

Initiatives are meant to inform our audiences of how our work extends out to the greater world. Clearly convey their purpose, impact and how people can get involved.


## Writing about upcoming events

Start with the essentials: what, when, where, cost and then follow with more specific details such as information about the people presenting or links to further background information.


## Writing profile pages

This is an opportunity for people’s individuality to come through. Make these personable, highlight people’s passions, expertise and interesting facts that connect them to the reader.


## Writing technical content

Someone reading technical content is usually looking to answer a specific question. That question might be broad or narrowly-focused, but either way our goal is to provide answers without distraction.

For each project, consider your audience’s background, goal, and current mood. Ask these questions:

* Is the reader a prospective user, a new user, or an experienced user? 
* What is the goal of the reader? To complete a task? To research a topic?
* Is the reader in the middle of a task? Are they in a hurry? Could they be frustrated?

We don’t want to overload a reader with unnecessary information, choices to make, or complex ideas or phrases, when we don’t have to. This is particularly critical when a user may be new and/or frustrated. When relevant, prime the reader with a brief outline of an article’s focus in an introductory paragraph or section, and stick to the topic at hand. Keep sentences, paragraphs, and procedural steps focused and concise.


### Drafting technical content

Before you begin writing a new article, reach out to a subject matter expert (like an engineer, tester, designer, researcher, or technical support advisor) to get as much information as possible. You may only use a small portion of what you learn, but it helps to have more information than you need to decide where to focus your article.

Consider how many articles are needed and what article types will best describe a new feature or tasks to the user.

Outline your article, then write a draft. Stay in touch with your subject matter expert and revise as needed for accuracy, consistency, and length.

When you’re happy with a draft, pass it to another technical writer for peer review. Then show it to a lead technical writer for additional review and revisions. For new content or highly complex content, send last draft to your subject matter expert for final approval.


### Writing technical content

When writing technical content, follow the style points outlined in the Voice and tone and Grammar and mechanics sections. Here are some more general pointers, too.

**Stay relevant to the title**
When a user clicks the title of an article, they expect to find the answer they want. Don’t stray too far from the title or topic at hand. Use links to make related content available. If you find you’re getting too far from the intended topic, then you may need to create a separate but related article.

**Keep headlines and paragraphs short and scannable**
Focused users often scan an article for the part that will answer their particular question. Be sure headlines are short, descriptive, and parallel, to facilitate scanning.

**Use second-person and describe actions to a user**
Technical content talks to users when support agents can’t.

**Strive for simplicity and clarity**
Be as clear as possible. Use simple words and phrases, avoid gerunds and hard-to-translate idioms or words, focus on the specific task, limit the number of sentences per paragraph. If you must include edge cases or tangentially related information, set it aside in a Before 
You Start list or Notes field.

**Provide context through embedded screenshots and GIFs**
Screenshots and GIFs may not be necessary for every article or process, but can be helpful to orient new users. Crop screenshots tightly around the action to focus attention.

### Editing technical content

We edit technical content based on three goals:
* Digestibility  
  * Cut or tighten redundancies, gerunds, adverbs, and passive constructions.  
  * Use the simplest word.  
  * Limit paragraphs to three sentences.  
* Consistency  
  * Use the labels and terminology used in the Agaric client's app.  
  * Use specific, active verbs for certain tasks.  
  * Choose basic words and phrases to facilitate consistency across translated content.  
* Helpfulness  
  * Stay conversational, using contractions when appropriate.  
  * Avoid qualifiers that muddy meaning.  
  * Express understanding when appropriate.  
  * Craft clear transitions from section to section to orient the reader.  

### Formatting technical content

Technical content uses organization, capitalization, and other formatting to help convey meaning. Although different articles are organized differently, some formatting tips are consistent throughout all technical content.

**Capitalization**
Capitalize proper names of Agaric products, features, pages, tools, and team names when directly mentioned. In step-by-step instructions, capitalize and italicize navigation and button labels as they appear in the app.

Find It  
Menu page, Settings page  
Training Team, Coding Team  
Navigate to the Modules page.  
Click Save & Close.  

**Headings**
Group article content with H2s and H3s. Use H2s to organize content by higher-level topics or goals, and use H3s within each section to separate supporting information or tasks.  
Upload a List  
Format your CSV File  
Import your CSV File  
Match Fields  
Best Practices for Lists  
List Collection  
List Management  
Email Content and Delivery  

**Ordered Lists**
Only use ordered lists for step-by-step instructions. Separate steps into logical chunks, with no more than 2 related actions per step. When additional explanation or a screenshot is necessary, use a line break inside the list item.

**Unordered Lists**
Use unordered lists to display examples, or multiple notes in a Notes block. If an unordered list comprises more than 10 items, use a table instead.

## Writing for Social Media
We use social media to build relationships with Agaric clients and supporters and share all the cool stuff we do. But it also creates opportunities to say the wrong thing, put off clients, and damage our brand. So we’re careful and deliberate in what we post to our social channels. This section lays out how we strike that delicate balance.

### Basics
Agaric has a presence on most major social media platforms. Here are our most active accounts and what we usually post on each:
* Twitter: Product news, brand marketing, events, media mentions, evergreen content, “we’re hiring!” posts  
* Facebook: Product news, brand marketing, events, media mentions, evergreen content, “we’re hiring!” posts  
* LinkedIn: Product news, recruiting content, media mentions, evergreen content

### Guidelines
Our writing for social media should generally follow the style points outlined in the Voice and tone and Grammar and mechanics sections. Here are some additional pointers, too.

**Write short, but smart**
Some social media platforms have a character limit; others don’t. But for the most part, we keep our social media copy short.
Twitter: 270 characters or less (this leaves room for a manual retweet and comments)
Facebook: No limit, but aim for 1-2 short sentences.
Instagram: No limit, but try to keep it to 1 sentence or a short phrase. Feel free to throw in an emoji.

To write short, simplify your ideas or reduce the amount of information you’re sharing—but not by altering the spelling or punctuation of the words themselves. It’s fine to use the shorter version of some words, like “info” for “information.” But do not use numbers and letters in place of words, like “4” instead of “for” or “u” instead of “you.”

### Engagement
Do your best to adhere to Agaric style guidelines when you’re using our social media channels to correspond with users. Use correct grammar and punctuation—and avoid excessive exclamation points.

When appropriate, you can tag the subject of your post on Twitter or Facebook. But avoid directly tweeting at or otherwise publicly tagging a post subject with messages like, “Hey, we wrote about you!” Never ask for retweets, likes, or favorites.
Yes: “We talked with @dinarcon about configuring YAML definition files https://agaric.coop/blog/drupal-migrations-reference-list-configuration-options-yaml-definition-files”
No: “Hey @mlncn, can you RT this post we wrote about the training you're giving? https://agaric.coop/blog/learn-how-migrate-drupal-8-successfully-nonprofit-technology-pre-conference-day”

### Hashtags
We employ hashtags rarely and deliberately. We may use them to promote an event or connect with users at a conference. Do not use current event or trending hashtags to promote Agaric unless it applies directly to our work (eg: #drupal #freesoftware #netneutrality).

### Trending topics
* Do not use social media to comment on trending topics or current events that are unrelated to Agaric.  
* Be aware of what’s going on in the news when you're publishing social content for Agaric.
* During major breaking news events, we turn off all promoted and scheduled social posts.  

### Writing for Accessibility
We’re always working to make our content more accessible and usable to the widest possible audience. Writing for accessibility goes way beyond making everything on the page available as text. It also affects the way you organize content and guide readers through a page. Depending on the audience and country, there may be laws governing the level of accessibility required. At minimum, an accessible version should be available. Accessibility includes users of all mental and physical capacities, whether situational (broken glasses!) or more permanent.

## Basics
We write for a diverse audience of readers who all interact with our content in different ways. We aim to make our content accessible to anyone using a screen reader, keyboard navigation, or Braille interface, and to users of all cognitive capabilities.
As you write, consider the following:
* Would this language make sense to someone who doesn’t work here?  
* Could someone quickly scan this document and understand the material?  
* If someone can’t see the colors, images or video, is the message still clear?  
* Is the markup clean and structured?  
* Mobile devices with accessibility features are increasingly becoming core communication tools, does this work well on them?  

Many of the best practices for writing for accessibility echo those for writing technical content, with the added complexity of markup, syntax, and structure.

## Guidelines

* Avoid directional language  
* Avoid directional instructions and any language that requires the reader to see the layout or design of the page. This is helpful for many reasons, including layout changes on mobile.  

Yes: “Select from these options” (with the steps listed after the title)  
No: “Select from the options in the right sidebar.”  

### Use a skip navigation link
Use a skip navigation link so that screen reader or keyboard-only users can avoid listening to or tabbing through many navigation elements before getting to the main content.

### Use headers
Headers should always be nested and consecutive. Never skip a header level for styling reasons. To help group sections, be sure the page title is H1, top-level sections are H2s, and subsequent inside those are H3 and beyond. Avoid excessive nesting.

### Employ a hierarchy
Put the most important information first. Place similar topics in the same paragraph, and clearly separate different topics with headings.
Starting with a simple outline that includes key messages can help you create a hierarchy and organize your ideas in a logical way. This improves scannability and encourages better understanding.
Make true lists instead of using a paragraph or line breaks.

### Label forms
Label inputs with clear names, and use appropriate tags. Think carefully about what fields are necessary, and especially which ones you mark as required. Label required fields clearly. The shorter the form, the better.

### Use descriptive links
Links should provide information on the associated action or destination. Try to avoid “click here” or “learn more.”

### Use plain language
Write short sentences and use familiar words. Avoid jargon and slang. If you need to use an abbreviation or acronym that people may not understand, explain what it means on first reference.

### Use alt text
The alt tag is the most basic form of image description, and it should be included on all images. The language will depend on the purpose of the image:  
* If it’s a creative photo or supports a story, describe the image in detail in a brief caption.  
* If the image is serving a specific function, describe what’s inside the image in detail. People who don’t see the image should come away with the same information as if they had.  
* If you’re sharing a chart or graph, include the data in the alt text so people have all the important information.  

Each browser handles alt tags differently. Supplement images with standard captions when possible.

### Make sure closed captioning is available
Closed captioning or transcripts should be available for all videos. The information presented in videos should also be available in other formats.

### Be mindful of visual elements
Aim for high contrast between your font and background colors. Tools in the resources section should help with picking accessible colors.

Images should not be the only method of communication, because images may not load or may not be seen. Avoid using images when the same information could be communicated in writing.

## Resources
* [Accessibility evaluation for web writers](http://www.4syllables.com.au/2013/05/writers-accessibility-evaluation/)  
* [Accessibility cheatsheet](http://bitsofco.de/2015/the-accessibility-cheatsheet/)  
* [WAVE Web Accessibility Evaluation Tool](http://wave.webaim.org/)  

## Writing for Translation
Agaric serves users in several countries and territories, not just the United States. As our user base grows, it becomes more and more important that our content is accessible to people around the world.

We call the process of writing copy for translation “internationalization.” This section will address things you can do to help international audiences, including translators, better comprehend your text.

### Basics
We try to write all of our content in standard, straightforward English that can be understood by users with limited English proficiency. It's much easier for a translator to clearly communicate ideas written in straightforward, uncomplicated sentences.
Here are some guiding principles for writing for international audiences:
Use active voice. We always aim for this, but it's especially important when writing for translation.

Use the subject-verb-object sentence structure. It’s not used by all languages, but it’s widely recognized.

Use positive words when talking about positive situations. For example, because a question like “Don’t you think she did a great job?” begins with a negative word, a non-native English speaker may interpret its implication as negative. A better version would be “She did a good job, right?”

### Guidelines
When writing for international audiences, we generally follow what's outlined in the Voice and tone and Grammar and mechanics sections. But in this section more than others, some style points contradict what's stated elsewhere in the guide. If you’re writing something to be translated, the guidelines in this section should take precedence.

### Consider cultural differences
Agaric’s voice is conversational and informal. However, in some cultures, informal text may be considered offensive. Check with your translator to see if this is the case for the particular language you’re writing for.

The translation company should give the option to translate in a formal or informal tone, if the language allows for it. (For example, in Spanish, it is possible to write informally where tú = you or formally where usted = you.)

When writing text that will be translated, be careful about making references to things of local or regional importance. These may not be recognizable to readers outside the US.

### Prioritize clarity
Keep your copy brief, but don’t sacrifice clarity for brevity. You may need to repeat or add words to make the meaning of your sentences clear to a translator.

#### Repeat verbs that have multiple subjects.
Yes: Customers who have ordered online can pick up their food at the cashier. Walk-in customers should stop by the cashier to order their food.  
No: Customers who have ordered online or who are walk-ins should stop at the cashier to order or pick up their food.  
Repeat helping verbs belonging to multiple verbs  
Yes: Agaric can build your website or can train your development team to build more powerful websites.
No: Agaric can build your website or train your development team to build more powerful websites. 

#### Repeat subjects and verbs
Yes: Most Agarics use contractions, but Micky does not. 
No: Most Agarics use contractions, but not Micky.  

#### Repeat markers in a list or series
Yes: Use Agaric's Find It platform to post opportunities, to list service providers, and to connect kids with activities. 
No: Use Agaric's Find It platform to post opportunities, list service providers, and connect kids with activities.

#### Leave in words like “then,” “a,” “the,” “to,” and “that," even if you think they could be cut  

Yes: If there is not a test site set up, then you’ll need to create a test site before you can safely evaluate functionality changes.  
No: If there is not a test site set up, you’ll need to create a test site before you can safely evaluate functionality changes.

Yes: When sending an email, it is necessary to have a “From:” name, a “From:” address, and a subject line.  
No: When sending an email, it is necessary to have a “From:” name, “From:” address, and subject line.  

Yes: Be sure that you are truly ready to show your work to the world before pushing your changes to live.  
No: Be sure you are truly ready to show your work to the world before pushing your changes to live.


#### Avoid ambiguity and confusion

Many words, parts of speech, and grammar mechanics we don’t think twice about have the potential to cause confusion for translators and non-native English speakers. Here are some of the big trouble spots to avoid.

#### Avoid unclear pronoun references

Yes: Many believe that making functionality changes directly to a live site is OK. Such action can actually cause a site to break. Making functionality changes directly to a live site is not recommended.
No: Many believe that making functionality changes directly to a live site is OK. This can cause a site to break. It is not recommended.

#### Avoid -ing words

In English, many different types of words end in -ing: nouns, adjectives, progressive verbs, etc. But a translator who is a non-native English speaker may not be able to recognize the distinctions and may try to translate them all in the same way.

Because of this, we want to avoid -ing words when possible. One exception to this rule is words like “graphing calculator” and “riding lawnmower,” where the -ing word is part of a noun’s name and can’t be worked around.
Here are some other cases where you might see -ing words, and suggestions for how to edit around them.

##### Gerunds

Yes: In this article we will talk about training participant signups.  
No: In this article we will talk about getting training participants.  

##### Adjectives

Yes: At the top of the page, there is Ben with a smile on his face.  
No: At the top of the page, there is a smiling Ben.  

##### Parts of verbs

Yes: Several developers are currently working on that feature.  
No: Several developers are working on that feature. (When you can’t easily avoid the -ing word, it may help to add an adverb to clarify the meaning.)  

##### Parts of phrases modifying nouns

Yes: From our backyard, we could hear the planes that took off from the airport.  
No: From our backyard, we could hear the planes taking off from the airport.  

#### Other words and mechanics to avoid

* Slang, idioms, and cliches  
* Contractions (English contractions may not be recognizable to all translators)  
* Shortened words, even if they’re common in English (use “application,” not “app”)  
* Uncommon foreign words (use "genuine,” not “bona fide”)  
* Unnecessary abbreviations (use "for example,” not “e.g.”)  
* Converting one part of speech into another if it isn’t already commonly used (use "Send us an email” instead of “message us”)  
* Non-standard or indirect verb usage (use “he says,” not “he’s like” or “he was all”)  
* Double negatives  
* Synonyms, generally. Don't use a lot of different words for the same thing in a single piece of writing. Instead of mixing it up with “campaign,” “newsletter,” “bulletin,” etc., pick one term and stick with it.

#### Beware words with multiple meanings

“Once” (could mean “one time,” “after,” “in the past,” or “when”)  
Yes: After you log in, you will see your account’s Dashboard.  
No: Once you log in, you will see your account’s Dashboard.  
“Right” (could mean “correct,” “the opposite of left,” “politically conservative,” etc.)  
Yes: In the File Manager, click the correct image and drag it to the pane at right.  
No: In the File Manager, click the right image and drag it to the right pane.  
“Since” (could refer to a point in time, or a synonym of “because”)  
Yes: Because you already have a complete mailing list, you can send your campaign at any time.  
No: Since you already have complete mailing list, you can send your campaign at any time.
“Require” plus an infinitive (could confuse the relationship between subject and object)  
Yes: Autoresponders can be configured and sent from paid accounts.  
No: A paid account is required to send autoresponders. (This could imply that users with paid accounts are required to send autoresponders.)  
“Has” or “have” plus past participle (could confuse the relationship between subject and object)  
Yes: The folder contains sent campaigns.  
No: The folder has sent campaigns.  

#### Numbers

**Measurements**
When writing for an international audience, use the metric system. Spell out all units and avoid abbreviation.

**Currency**
Many countries call their currency "the dollar," but the value is going to differ between countries. The US dollar is not the same as the Canadian dollar, for example. So it’s important to specify.

Avoid colloquial phrases that relate to money, like “five-and-dime,” “greenbacks,” or “c-notes.” These won’t translate well.

## Word list

  * add-on (noun, adjective), add on (verb)  
  * back end (noun), back-end (adjective)  
  * beta  
  * checkbox  
  * co-op
  * cooperative
  * coworker
  * Cloudflare
  * double-click
  * dropdown (noun, adjective), drop down (verb)
  * e-commerce (the industry)
  * e-mail
  * ePub
  * e-mail (always hyphenate, never capitalize unless it begins a sentence)
  * emoji (singular and plural)
  * front end (noun), front-end (adjective)
  * geolocation
  * hashtag
  * homepage
  * integrate
  * internet (only capitalize unless if it begins a sentence)
  * login (noun, adjective), log in (verb)
  * Like (the social media activity)
  * May First Movement Technology, or May First on subsequent uses (not MayFirst or MFPL or the old name, May First / People Link)
  * Nextcloud
  * OK
  * online (never capitalize unless it begins a sentence)
  * opt-in (noun, adjective) , opt in (verb)
  * pop-up (noun, adjective), pop up (verb)
  * signup (noun, adjective), sign up (verb)
  * sync
  * tweet, retweet
  * username
  * URL
  * web hosting
  * website
  * WiFi

## Words to avoid

  * automagically
  * funnel, incentivize, leverage, disruption, thought leader, or other fluffy corporate terms
  * internets, interwebs, or any other variation of the word “internet”
  * ninja, rockstar, wizard, unicorn (unless referring to a literal ninja, rockstar, wizard, or unicorn)
  * young, old, elderly, or any other word describing a person's age
  * crushing it, killing it
  * crazy, insane, or similar words to describe people

## Styleguide credit

Adapted from [MailChimp](https://styleguide.mailchimp.com/) and available under a Creative Commons Attribution-NonCommercial 4.0 International license.

```{admonition} See also

  * Information about [copyrights and trademarks](copyright-and-trademarks).
```
